{% extends "aldryn_faq/base.html" %}
{% load i18n cms_tags %}

{% block content %}
    <div class="container">
        <div class="row">
            <div class="col-md-17 col-md-push-7">
                <div class="aldryn aldryn-faq">
                    {% block faq_content %}
                        {% static_placeholder "faq_article_list" %}
                    {% endblock %}
                </div>
            </div>
            <div class="col-md-7 col-md-pull-17 aldryn-faq aldryn-faq-sidebar">
                {% block faq_sidebar %}
                    {% include "aldryn_faq/plugins/category_list.html" with categories=category_list %}
                {% endblock %}
            </div>
        </div>
    </div>
{% endblock content %}
