# -*- coding: utf-8 -*-

from __future__ import unicode_literals

__version__ = '1.2.1'

# TODO: Check if these are still required
request_faq_category_identifier = 'aldryn_faq_current_category'
request_faq_question_identifier = 'aldryn_faq_current_question'
