{% extends "aldryn_faq/fullwidth.html" %}
{% load i18n cms_tags %}

{% block breadcrumb %}{% endblock %}

{% block faq_content %}
    <article class="aldryn aldryn-faq aldryn-faq-detail">
        <a href="{{ category_url }}" class="label label-primary">
            {% render_model object "category" "category" %}
        </a>

        {% if object.tags.all %}
            <div class="tags pull-right">
                {% for tag in object.tags.all %}
                    <span class="badge">{{ tag }}</span>
                {% endfor %}
            </div>
        {% endif %}

        <h2>{% render_model object "title" %}</h2>

        {% if question.answer_text %}
            <div class="lead">
                {% render_model object "answer_text" "answer_text" "" safe %}
            </div>
        {% endif %}

        <div class="content">
            {% render_placeholder object.answer 800 %}
        </div>
    </article>
{% endblock %}

{% block faq_footer %}
    {% include "aldryn_faq/includes/pager.html" with title=_("Back to Category") slug=category_url %}
{% endblock %}
