{% load cms_tags i18n %}

<div class="list-group">
    {% for question in object_list %}
        {% if view.config.app_data.config.show_description %}
            <a href="{{ question.get_absolute_url }}" class="list-group-item">
                <h3 class="list-group-item-heading">
                    {% render_model question "title" %}
                    {% for tag in question.tags.all %}
                        <span class="badge">{{ tag }}</span>
                    {% endfor %}
                </h3>
                <div class="list-group-item-text">
                    {% render_model question "answer_text" %}
                </div>
            </a>
        {% else %}
            <a href="{{ question.get_absolute_url }}" class="list-group-item">
                {% render_model question "title" %}
                {% for tag in question.tags.all %}
                    <span class="badge">{{ tag }}</span>
                {% endfor %}
            </a>
        {% endif %}
    {% empty %}
        <p class="list-group-item">{% trans "No entry found." %}</p>
    {% endfor %}
</div>
