{% extends "aldryn_faq/two_column.html" %}
{% load i18n cms_tags %}

{% block faq_content %}
    {% with list="true" %}
        {% include "aldryn_faq/includes/question_list.html" %}
    {% endwith %}

    {% url 'aldryn_faq:faq-category-list' as category_list_url %}
    {% include "aldryn_faq/includes/pager.html" with title=_("Back to Overview") slug=category_list_url %}
{% endblock %}
