{% extends "aldryn_faq/base.html" %}
{% load cms_tags %}

{% block faq_content %}
    {% static_placeholder "faq_content" %}
    {% include "aldryn_faq/plugins/category_list.html" with categories=category_list %}
{% endblock %}
