{% extends "aldryn_faq/base.html" %}
{% load i18n cms_tags %}

{% block content_faq %}
<div class="faq-detail">
	<h2>{% render_model object "category" "category" %}</h2>
	<h3>{% render_model object "title" %}</h3>
	{% if question.answer_text %}<div class="faq-answer">{% render_model object "answer_text" "answer_text" "" safe %}</div>{% endif %}
	<div class="faq-content">{% render_placeholder object.answer 660 %}</div>
	<p class="faq-back"><a href="{% url 'aldryn_faq:faq-category' object.category.slug %}">{% trans "Back" %}</a></p>
</div>
{% endblock %}