{% load i18n %}

<div class="aldryn-faq-pager">
    <ul class="pager">
        <li>
            <span class="pager-back">
                – <a href="{{ slug }}">{{ title }}</a> –
            </span>
        </li>
    </ul>
</div>
