{% extends "aldryn_faq/base.html" %}
{% load i18n cms_tags %}

{% block content %}
    <div class="container">
        <div class="row">
            <div class="col-md-16 col-md-push-4">
                <div class="aldryn aldryn-faq">
                    {% block faq_content %}{% endblock %}
                </div>
            </div>
        </div>

        <div class="aldryn aldryn-faq">
            {% block faq_footer %}{% endblock %}
        </div>
    </div>
{% endblock content %}
